@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.9';
+our $VERSION = '0.9001';
 
 use warnings;
 use strict;
@@ -11,16 +11,15 @@ use strict;
 use parent qw( Graph );
 
 use Carp qw( croak );
-use Readonly;
 
-Readonly my $WEIGHT => 'weight';
+use constant WEIGHT => 'weight';
 
 
 sub populate {
     my ($self, $data, $attr) = @_;
 
     # Set the default attribute.
-    $attr ||= $WEIGHT;
+    $attr ||= WEIGHT;
 
     # What type of data are we given?
     my $data_ref = ref $data;
@@ -116,7 +115,7 @@ sub get_cost {
     croak 'ERROR: No vertex given to get_cost()' unless defined $v;
 
     # Default to weight.
-    $attr ||= $WEIGHT;
+    $attr ||= WEIGHT;
 
     # Return the edge attribute if given a list.
     return $self->get_edge_attribute(@$v, $attr) || 0 if ref $v eq 'ARRAY';
@@ -241,7 +240,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.9
+version 0.9001
 
 =head1 SYNOPSIS
 
@@ -261,8 +260,6 @@ version 0.9
  my ( $lightest, $heaviest ) = $gw->vertex_span;
  ( $lightest, $heaviest ) = $gw->edge_span;
 
- my $weight = $gw->path_cost( \@vertices );
-
  my $attr = 'probability';
  $gw = Graph::Weighted->new;
  $gw->populate(
@@ -276,6 +273,10 @@ version 0.9
  );
  $gw->dump($attr);
 
+ my $cost = $gw->get_cost( [0, 1], $attr );
+
+ $cost = $gw->path_cost( [0, 3, 1, 2], $attr );
+
 =head1 DESCRIPTION
 
 A C<Graph::Weighted> object is a subclass of the L<Graph> module with attribute
@@ -352,67 +353,13 @@ L<Graph/"All-Pairs Shortest Paths (APSP)">.
 
 Print out the graph showing vertices, edges and costs.
 
-=head1 EXAMPLES
-
-=head2 Shortest Paths
-
-  my $g = Graph::Weighted->new();
-  $g->populate({
-    A => { B => 4, C => 2 },
-    B => { C => 5, D => 10 },
-    C => { E => 3 },
-    D => { F => 11 },
-    E => { D => 4 },
-    F => { },
-  });
-  my @path = $g->SP_Dijkstra( 'A', 'F' ); # A->C->E->D->F
-  print 'Dijkstra: ', join( '->', @path ), "\n";
-
-  $g = Graph::Weighted->new();
-  $g->populate({
-    S => { A =>  7, B => 6 },
-    A => { C => -3, T => 9 },
-    B => { A =>  8, C => 5, T => -4 },
-    C => { B => -5 },
-    T => { },
-  });
-  @path = $g->SP_Bellman_Ford( 'S', 'T' ); # S->A->C->B->T
-  print 'Bellman-Ford: ', join( '->', @path ), "\n";
-
-  $g = Graph::Weighted->new();
-  $g->populate({
-    1 => { 2 => 8, 4 => 1 },
-    2 => { 3 => 1 },
-    3 => { 1 => 4 },
-    4 => { 2 => 2, 3 => 9 },
-  });
-  my $apsp = $g->APSP_Floyd_Warshall();
-  @path = $apsp->path_vertices( 1, 3 ); # 1->4->2->3
-  print 'Floyd-Warshall: ', join( '->', @path ), "\n";
-
-=head2 Minimum Spanning Trees
-
-  my $g = Graph::Weighted->new( undirected => 1 );
-  $g->populate({
-        A => { B => 4, F => 2 },
-        B => { C => 6, F => 5 },
-        C => { F => 1 },
-        D => { },
-  });
-
-  my @path = $g->MST_Kruskal; # A=B,A=F,C=F
-  print 'Kruskal: ', join( '->', @path ), "\n";
-
-  @path = $g->MST_Prim; # same
-  print 'Prim: ', join( '->', @path ), "\n";
-
 =head1 SEE ALSO
 
 L<Graph>, the parent of this module
 
 L<Graph::Easy::Weighted>, the sibling
 
-The F<eg/*> and F<t/*> file sources
+The F<eg/*> and F<t/*> programs in this distribution
 
 =head1 AUTHOR
 
@@ -420,7 +367,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Gene Boggs.
+This software is copyright (c) 2020 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
